@@ -1,4 +1,4 @@
-# Copyrights 2001-2022 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2023 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.03.
@@ -8,20 +8,21 @@
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.012';
+$VERSION = '3.013';
 
 
 use strict;
 use warnings;
 
 use Mail::Box::FastScalar;
+use Mail::Box::Parser::Perl ();
 
 
 sub read($@)
 {   my ($class, $from, %args) = @_;
+
     my ($filename, $file);
     my $ref       = ref $from;
-
     if(!$ref)
     {   $filename = 'scalar';
         $file     = Mail::Box::FastScalar->new(\$from);
@@ -51,18 +52,18 @@ sub read($@)
         return undef;
     }
 
-    my $strip_status = exists $args{strip_status_fields}
-                     ? delete $args{strip_status_fields}
-                     : 1;
-
-    require Mail::Box::Parser::Perl;  # not parseable by C parser
+    my $strip_status
+      = exists $args{strip_status_fields}
+      ? delete $args{strip_status_fields}
+      : 1;
 
+    # Not parseable by the C implementation
     my $parser = Mail::Box::Parser::Perl->new
-     ( %args
-     , filename  => $filename
-     , file      => $file
-     , trusted   => 1
-     );
+      ( %args
+      , filename  => $filename
+      , file      => $file
+      , trusted   => 1
+      );
 
     my $self = $class->new(%args);
     $self->readFromParser($parser, $args{body_type});
@@ -71,8 +72,8 @@ sub read($@)
     $parser->stop;
 
     my $head = $self->head;
-    $head->set('Message-ID' => '<'.$self->messageId.'>')
-        unless $head->get('Message-ID');
+    $head->get('Message-ID')
+        or $head->set('Message-ID' => '<'.$self->messageId.'>');
 
     $head->delete('Status', 'X-Status') if $strip_status;
 
