@@ -1,4 +1,4 @@
-# Copyrights 2001-2022 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2023 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.03.
@@ -8,7 +8,7 @@
 
 package Mail::Message::Field::Addresses;
 use vars '$VERSION';
-$VERSION = '3.012';
+$VERSION = '3.013';
 
 use base 'Mail::Message::Field::Structured';
 
@@ -113,11 +113,13 @@ sub parse($)
     my ($group, $email) = ('', undef);
     $string =~ s/\s+/ /gs;
 
+  ADDRESS:
     while(1)
     {   (my $comment, $string) = $self->consumeComment($string);
+        my $start_length = length $string;
 
-        if($string =~ s/^\s*\;//s ) { $group = ''; next }  # end group
-        if($string =~ s/^\s*\,//s ) { next }               # end address
+        if($string =~ s/^\s*\;//s ) { $group = ''; next ADDRESS }  # end group
+        if($string =~ s/^\s*\,//s ) { next ADDRESS}               # end address
 
         (my $email, $string) = $self->consumeAddress($string);
         if(defined $email)
@@ -128,25 +130,33 @@ sub parse($)
         else
         {   # Pattern not plain address
             my $real_phrase = $string =~ m/^\s*\"/;
-            (my $phrase, $string) = $self->consumePhrase($string);
+            my @words;
 
-            if(defined $phrase)
-            {   ($comment, $string) = $self->consumeComment($string);
+            # In rfc2822 obs-phrase, we can have more than one word with
+            # comments inbetween.
+         WORD:
+            while(1)
+            {   (my $word, $string) = $self->consumePhrase($string);
+                defined $word or last;
+
+                push @words, $word if length $word;
+                ($comment, $string) = $self->consumeComment($string);
 
                 if($string =~ s/^\s*\://s )
-                {   $group = $phrase;
+                {   $group = $word;
                     # even empty groups must appear
-                    $self->addGroup(name=>$group) unless $self->group($group);
-                    next;
+                    $self->addGroup(name => $group) unless $self->group($group);
+                    next ADDRESS;
                 }
             }
+            my $phrase = @words ? join ' ', @words : undef;
 
             my $angle;
             if($string =~ s/^\s*\<([^>]*)\>//s) { $angle = $1 }
             elsif($real_phrase)
             {   $self->log(ERROR => "Ignore unrelated phrase `$1'")
                     if $string =~ s/^\s*\"(.*?)\r?\n//;
-                next;
+                next ADDRESS;
             }
             elsif(defined $phrase)
             {   ($angle = $phrase) =~ s/\s+/./g;
@@ -165,10 +175,12 @@ sub parse($)
 
         $self->addAddress($email, group => $group) if defined $email;
         return 1 if $string =~ m/^\s*$/s;
+
+        # Do not get stuck on illegal characters
+        last if $start_length == length $string;
    }
 
-   $self->log(WARNING => 'Illegal part in address field '.$self->Name.
-        ": $string\n");
+   $self->log(WARNING => 'Illegal part in address field '.$self->Name. ": $string\n");
 
    0;
 }
@@ -180,11 +192,11 @@ sub produceBody()
    @groups > 1 or return $groups[0]->string;
 
    my $plain
-    = $groups[0]->name eq '' && $groups[0]->addresses
-    ? (shift @groups)->string.','
-    : '';
+     = $groups[0]->name eq '' && $groups[0]->addresses
+     ? (shift @groups)->string.','
+     : '';
 
-   join ' ', $plain, map({$_->string} @groups);
+   join ' ', $plain, (map $_->string, @groups);
 }
 
 
@@ -202,11 +214,12 @@ sub consumeAddress($@)
         $local =~ s/\s//g if defined $local;
     }
 
-    return (undef, $string)
-        unless defined $local && $shorter =~ s/^\s*\@//;
+    defined $local && $shorter =~ s/^\s*\@//
+        or return (undef, $string);
   
     (my $domain, $shorter, my $domcomment) = $self->consumeDomain($shorter);
-    return (undef, $string) unless defined $domain;
+    defined $domain
+        or return (undef, $string);
 
     # loccomment and domcomment ignored
     my $email   = Mail::Message::Field::Address
